pydeseq2.ds.DeseqStats
======================

.. currentmodule:: pydeseq2.ds

.. autoclass:: DeseqStats

   .. rubric:: Methods

   .. autosummary::

      ~DeseqStats.lfc_shrink
      ~DeseqStats.run_wald_test
      ~DeseqStats.summary
